@@ -40,6 +40,24 @@ class TestToMMLibrary(unittest.TestCase):
         dsl.get_parameter("x")
         assert dsl.get_parameter("y", 222) == 222
 
+    def test_parameters_precedence(self):
+        """
+        Environment over mmlibrary.
+        """
+        params = {"x": 1}
+        class MyMM(object):
+            def get_arguments(self):
+                return params
+        dsl = DSLibraryViaMMLibrary(_mm=MyMM())
+        r = dsl.get_parameters()
+        assert r == {"x": 1}
+        dsl.get_parameter("x")
+        assert dsl.get_parameter("y", 222) == 222
+        # insert 'specification' parameters
+        dsl = DSLibraryViaMMLibrary(_mm=MyMM(), spec={"parameters": {"x": 3}})
+        self.assertEqual(dsl.get_parameter("x"), 3)
+        self.assertEqual(dsl.get_parameters(), {"x": 3})
+
     def test_open_run_data(self):
         class MyMM(object):
             def __init__(self):
